@@ -26,7 +26,6 @@ import gtk, gobject
 from solfege import gu
 from solfege import inputwidgets
 from solfege.specialwidgets import RandomTransposeDialog
-from solfege.exceptiondialog import ExceptionDialog
 from solfege import soundcard, mpd
 from solfege import utils
 from solfege import cfg, lessonfile, osutils, const
@@ -116,8 +115,8 @@ class MelodicIntervalTeacher(Teacher):
     """
     Base class for interval exercises where
     you can have more than one interval.
-    When this class was created it was used by melodic-intevall
-    and sing-interval.
+    When this class was created it was used by melodicinterval
+    and singinterval.
     """
     OK = 0
     ERR_PICKY = 1
@@ -414,7 +413,9 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
                 b = b.split('-')[0]
             setattr(self, 'g_%s' % b, button)
     def _std_buttons_start_sensitivity(self):
-        if 'new' in self._std_buttons:
+        # Values like 'new-interval', 'new-tone' and 'new-chord' and
+        # possible others can be added to ._std_buttons
+        if [n for n in self._std_buttons if n.split("-")[0] == 'new']:
             self.g_new.set_sensitive(True)
         for b in ('repeat', 'repeat_slowly', 'repeat_arpeggio',
             'repeat_melodic', 'guess_answer', 'play_tonic', 'play_music',
@@ -453,7 +454,9 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
             else:
                 self.g_show.hide()
     def std_buttons_new_question(self):
-        if 'new' in self._std_buttons:
+        # Values like 'new-interval', 'new-tone' and 'new-chord' and
+        # possible others can be added to ._std_buttons
+        if [n for n in self._std_buttons if n.split("-")[0] == 'new']:
             self.g_new.set_sensitive(
                 not self.get_bool('config/picky_on_new_question'))
         for s in ('repeat', 'repeat_slowly', 'repeat_arpeggio',
@@ -478,7 +481,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
             self.std_buttons_start_practise()
         else:
             for name in self._std_buttons:
-                if name not in ('new', 'repeat', 'give_up'):
+                if name.split("-")[0] not in ('new', 'repeat', 'give_up'):
                     if '-' in name:
                         name = name.split('-')[0]
                     getattr(self, 'g_%s' % name).hide()
@@ -487,7 +490,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
         # self.get_bool('config/picky_on_new_question') is True, but
         # we does it every time just in case the user have changed the
         # variable between clicking 'New' and answering the question.
-        if 'new' in self._std_buttons:
+        if [n for n in self._std_buttons if n.split("-")[0] == 'new']:
             self.g_new.set_sensitive(True)
             self.g_new.grab_focus()
         if 'show' in self._std_buttons:
@@ -500,7 +503,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
         if 'give_up' in self._std_buttons:
             self.g_give_up.set_sensitive(True)
     def std_buttons_give_up(self):
-        if 'new' in self._std_buttons:
+        if [n for n in self._std_buttons if n.split("-")[0] == 'new']:
             self.g_new.set_sensitive(True)
             self.g_new.grab_focus()
         if 'show' in self._std_buttons:
@@ -603,11 +606,8 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
         spin.set_sensitive(b.get_active())
         hbox.pack_start(spin, False)
     def _lessonfile_exception(self, exception, sourcefile, lineno):
-        m = ExceptionDialog(exception)
-        try:
-            idx = exception.m_question_idx
-        except AttributeError:
-            idx = self.m_t.m_P._idx
+        m = gu.ExceptionDialog(exception)
+        idx = self.m_t.m_P._idx
         if idx is not None:
             m.add_text(_('Please check question number %(idx)i in the lesson file "%(lf)s".') % {'idx': self.m_t.m_P._idx+1, 'lf': self.m_t.m_P.m_filename})
         if 'm_nonwrapped_text' in dir(exception):
@@ -620,18 +620,14 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
         m.run()
         m.destroy()
     def _mpd_exception(self, exception, sourcefile, lineno):
-        try:
-            idx = exception.m_question_idx + 1
-        except AttributeError:
-            idx = self.m_t.m_P._idx + 1
-        m = ExceptionDialog(exception)
+        m = gu.ExceptionDialog(exception)
         if 'm_mpd_varname' in dir(exception):
             m.add_text(_('Failed to parse the music in the variable "%(varname)s" in question number %(idx)i in the lesson file "%(lf)s".') % {
-                'idx': idx,
+                'idx': self.m_t.m_P._idx + 1,
                 'lf': lessonfile.uri_expand(self.m_t.m_P.m_filename),
                 'varname': exception.m_mpd_varname})
         else:
-            m.add_text(_('Failed to parse the music for question number %(idx)i in the lesson file "%(lf)s".') % {'idx': idx, 'lf': lessonfile.uri_expand(self.m_t.m_P.m_filename)})
+            m.add_text(_('Failed to parse the music for question number %(idx)i in the lesson file "%(lf)s".') % {'idx': self.m_t.m_P._idx + 1, 'lf': lessonfile.uri_expand(self.m_t.m_P.m_filename)})
         if 'm_mpd_badcode' in dir(exception):
             m.add_nonwrapped_text(exception.m_mpd_badcode)
         m.add_text(_('The exception was caught in\n"%(filename)s", line %(lineno)i.') % {'filename': sourcefile, 'lineno': lineno})
@@ -685,7 +681,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
             return True
         elif isinstance(e, osutils.OsUtilsException):
             cleanup_function()
-            solfege.win.display_exception_message(e)
+            gu.display_exception_message(e)
             return True
         return False
 
@@ -876,9 +872,9 @@ class LessonbasedGui(Gui):
         response = dlg.run()
         if response == gtk.RESPONSE_OK:
             self.m_t.m_P.header.random_transpose = dlg.get_value()
-            if self.m_t.m_P.header.random_transpose == True:
+            if self.m_t.m_P.header.random_transpose[0] == True:
                 self.g_random_transpose.set_text(_("Yes"))
-            elif self.m_t.m_P.header.random_transpose == False:
+            elif self.m_t.m_P.header.random_transpose[0] == False:
                 self.g_random_transpose.set_text(_("No"))
             else:
                 self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
@@ -908,6 +904,7 @@ class LessonbasedGui(Gui):
             else:
                 solfege.win.display_in_musicviewer(self.m_t.m_P.get_music(varname))
         except mpd.MpdException, e:
+            self.m_t.m_P.get_question()[varname].complete_to_musicdata_coords(self.m_t.m_P, e)
             e.m_mpd_varname = varname
             e.m_mpd_badcode = self.m_t.m_P.get_question()[varname].get_err_context(e, self.m_t.m_P)
             if not self.standard_exception_handler(e):
