@@ -743,7 +743,7 @@ def parse_to_score_object(music):
     for toc, toc_data in lexer:
         try:
             if toc_data.m_duration:
-                cur_duration = toc_data.m_duration
+                cur_duration = toc_data.m_duration.clone()
         except AttributeError:
             pass
         if toc == Lexer.STAFF:
@@ -833,6 +833,7 @@ def parse_to_score_object(music):
                 if times:
                     times = None
                     cur_voice.end_tuplet()
+                    cur_duration.m_tuplet = Rat(1, 1)
                 else:
                     context = TOPLEVEL
             else:
@@ -849,7 +850,7 @@ def parse_to_score_object(music):
             tie_is_in_the_air = 1
         elif toc == Lexer.NOTE and (context in [NOTES, CHORD, START_OF_CHORD]):
             if not getattr(toc_data, 'm_duration', None):
-                toc_data.m_duration = cur_duration
+                toc_data.m_duration = cur_duration.clone()
             if times:
                 toc_data.m_duration.m_tuplet = times
             if context in [NOTES, START_OF_CHORD]:
@@ -857,7 +858,7 @@ def parse_to_score_object(music):
             if relative_mode:
                 toc_data.m_pitch = musicalpitch_relative(
                                           relto, toc_data.m_pitch)
-                relto = toc_data.m_pitch
+                relto = toc_data.m_pitch.clone()
             if transpose_pitch:
                 toc_data.transpose(transpose_pitch)
             cur_voice.add_notehead(timepos, toc_data, stem_dir)
@@ -873,17 +874,17 @@ def parse_to_score_object(music):
                 context = CHORD
         elif toc == Lexer.SKIP and context == NOTES:
             if toc_data:
-                cur_duration = toc_data
+                cur_duration = toc_data.clone()
             else:
-                toc_data = cur_duration
+                toc_data = cur_duration.clone()
             last_pos = timepos
             timepos = timepos + toc_data.get_rat_value()
         elif toc == Lexer.REST and context == NOTES:
             cur_voice.announce_timepos(timepos)
             if toc_data.m_duration:
-                cur_duration = toc_data.m_duration
+                cur_duration = toc_data.m_duration.clone()
             else:
-                toc_data.m_duration = cur_duration
+                toc_data.m_duration = cur_duration.clone()
             cur_voice.add_rest(toc_data.m_duration, timepos)
             last_pos = timepos
             timepos += toc_data.m_duration.get_rat_value()
