@@ -1,6 +1,5 @@
+
 import glob
-import sys
-sys.path.insert(0, ".")
 import os
 import glob
 import shutil
@@ -16,17 +15,13 @@ for lang in gtk_po:
     if os.path.split(lang)[-1] not in sol_po:
         shutil.rmtree(lang)
 
-for d in glob.glob("win32/python/Lib/*/test"):
-    shutil.rmtree(d)
+#for d in glob.glob("win32/python/Lib/*/test"):
+#    shutil.rmtree(d)
 
-shutil.rmtree("win32/python/Tools/")
-shutil.rmtree("win32/python/tcl/")
-shutil.rmtree("win32/python/Lib/test/")
-shutil.rmtree("win32/python/Lib/lib2to3")
-shutil.rmtree("win32/python/Lib/lib-tk")
-shutil.rmtree("win32/python/Lib/idlelib")
-shutil.rmtree("win32/python/Lib/distutils")
-shutil.rmtree(r"win32\python\include")
+shutil.rmtree("win32/bin/Lib/test/")
+shutil.rmtree("win32/bin/Lib/lib-tk")
+shutil.rmtree("win32/bin/Lib/idlelib")
+shutil.rmtree("win32/bin/Lib/distutils")
 for fn in glob.glob("win32/share/locale/*"):
     if not os.path.split(fn)[1] in solfege.languages.languages:
         shutil.rmtree(fn)
